@@ -5,8 +5,8 @@ from . import exceptions
 from . import helpers
 
 
-__all__ = exceptions.__all__ + ['Bitpin']
-__version__ = '0.1.2'
+__all__ = ['Bitpin']
+__version__ = '0.1.3'
 __author__ = 'AMiWR'
 
 
