@@ -106,6 +106,9 @@ class Bitpin:
         if url.startswith('/'):
             url = url[1:]
 
+        if not url.endswith('/'):
+            url += '/'
+
         return f'{self.__base_url}/{url}'
 
     def __make_headers(self, func_name: str, auth: t.Optional[bool] = True) -> t.Dict:
@@ -656,3 +659,25 @@ class Bitpin:
         )
 
         return self._process_response(f_name, response, f_args)
+
+    def balances(self):
+        """
+        Get balances.
+
+        :return: Recent trades
+        :rtype: dict
+        """
+
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        url = '/v1/wlt/wallets/'
+
+        response = self._request(
+            f_name,
+            'GET',
+            url,
+            auth=True,
+        )
+
+        return self._process_response(f_name, response, f_args)
